Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Consumer ¶
Consumes an context object, possibly writing output to the Writer Normally, this is an abstraction for a template, but in tests, we use this to collect and validate the context object generated.
type Global ¶
type Global interface {
Title() string
Description() string
URL() url.Reverser
// Used in tests to compare contexts
Equals(Global) bool
}
Global context
type List ¶
type PathComponent ¶
type PathComponent interface {
Name() string
FullPath() string
IsLast() bool
Equals(PathComponent) bool
}
func NewPath ¶
func NewPath(path string) []PathComponent
type RepoGlobal ¶
Originally named Repo, but renamed to RepoGlobal to resolve conflict with the embedded Repo object and the Repo() method in subclasses
type RepoLog ¶
type RepoLog interface {
RepoGlobal
}
type RepoRefs ¶
type RepoRefs interface {
RepoGlobal
}
type RepoRoot ¶
Source Files
¶
- consumer.go
- global.go
- list.go
- repo-log.go
- repo-refs.go
- repo-root.go
- repo-tree.go
- repo.go
Click to show internal directories.
Click to hide internal directories.